<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:external="http://www.seapine.com" exclude-result-prefixes="external" id="TT V5.0 DefectDetailReport.xslt">

	<xsl:output method="html" version="4.0" encoding="iso-8859-1" indent="yes" />

	<!-- Indicates whether empty fields should be displayed in the report -->
	<xsl:param name="DisplayEmptyFields" select="true()" />

	<!-- Contains the default settings for the table containing the page header -->
	<xsl:attribute-set name="defect-pageheader-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains external image tag for the image in the page header -->
	<xsl:attribute-set name="report-pageheader-image">
		<xsl:attribute name="src">
			<xsl:value-of select="external:get-server-image('seapinelogo.jpg')" disable-output-escaping = "yes" />
		</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for table cell containing the image in the page header -->
	<xsl:attribute-set name="report-pageheader-image-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report title in the page header -->
	<xsl:attribute-set name="report-pageheader-title-format">
		<xsl:attribute name="align">right</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the table containing the header info for each defect -->
	<xsl:attribute-set name="defect-header-row-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">2</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
		<xsl:attribute name="bgcolor">#2B558A</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for cells within the header info for each defect -->
	<xsl:attribute-set name="defect-header-row-cell-format">
		<xsl:attribute name="width">33%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectHeaderRowClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the tables used within the detail portion of the report -->
	<xsl:attribute-set name="report-detail-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">3</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the 3-accross cells within the detail port of the report -->
	<xsl:attribute-set name="report-detail-cell-format">
		<xsl:attribute name="width">33%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the cells containing the title for note type fields -->
	<xsl:attribute-set name="report-detail-notes-title-format">
		<xsl:attribute name="width">15%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the cells containing the note type fields -->
	<xsl:attribute-set name="report-detail-notes-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the created by detail cells -->
	<xsl:attribute-set name="report-detail-sccfilecell-format">
		<xsl:attribute name="width">25%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the horizontal rule between defect events -->
	<xsl:attribute-set name="report-detail-event-rule-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="align">center</xsl:attribute>
		<xsl:attribute name="size">1</xsl:attribute>
	</xsl:attribute-set>

	<!-- Defines the default font settings used in the report -->
	<xsl:template name="DefineStyles">
		<STYLE>  
		 		.ReportTitleClass	{
					FONT-FAMILY: 'serif';
					FONT-SIZE: 30px;
					COLOR: #2B558A;
					FONT-WEIGHT:bold;
				}
	    </STYLE>
		<STYLE>  
		 		.DefectHeaderRowClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 11px;
					color: white;
					font-weight:bold;
					text-align: left;
					background-color:  #2B558A;
				}
	    </STYLE>
		<STYLE>  
		 		.DefectDetailRowTitleClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:bold;
					text-align: left;
					background-color:  white;
				}
	    </STYLE>
		<STYLE>  
		 		.DefectDetailRowDataClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:normal;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
	</xsl:template>

	<!-- Displays a user's name in the proper format -->
	<xsl:template name="display_user_name">
		<xsl:if test="(string-length(last-name) = 0) and (string-length(first-name) = 0)">
      			Unknown
      		</xsl:if>
		<xsl:if test="(string-length(last-name) > 0)">
			<xsl:value-of select="last-name" disable-output-escaping = "yes" />
			<xsl:if test="(string-length(first-name) > 0)">, </xsl:if>
		</xsl:if>
		<xsl:if test=" (string-length(first-name) > 0)">
			<xsl:value-of select="first-name" disable-output-escaping = "yes" />
		</xsl:if>
	</xsl:template>

	<!-- Outputs the Report Header -->
	<xsl:template name="pageheader">
		<table xsl:use-attribute-sets="defect-pageheader-table-format">
			<tr>
				<td xsl:use-attribute-sets="report-pageheader-image-format">
					<img xsl:use-attribute-sets="report-pageheader-image" />
				</td>
				<td xsl:use-attribute-sets="report-pageheader-title-format">
					<xsl:apply-templates select="ancestor-or-self::TestTrackData/Title" />
				</td>
			</tr>
		</table>
	</xsl:template>

	<!-- Displays the Defect Header Area of the Detail Report -->
	<xsl:template name="detail_defect_header_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="defect-header-row-table-format">
					<xsl:if test="defect-number or date-entered or product"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="defect-number/@field-label" disable-output-escaping = "yes" />
								<xsl:text></xsl:text>
								<xsl:value-of select="defect-number" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="date-entered/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="date-entered" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="product/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="product" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="entered-by or component"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">&#160;</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="entered-by/@field-label" disable-output-escaping = "yes" />
								<xsl:for-each select="entered-by">
									<xsl:call-template name="display_user_name" />
								</xsl:for-each>
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="component/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="component" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect status row of the Defect Detail Report -->
	<xsl:template name="detail_defect_status_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="defect-status or severity"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format" colspan="2">
								<xsl:value-of select="defect-status/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="defect-status" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="severity/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="severity" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="type or priority or disposition"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="type/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="type" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="priority/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="priority" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="disposition/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="disposition" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="reference"> <!-- hide row if field is hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="reference/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="reference" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format" />
							<td xsl:use-attribute-sets="report-detail-cell-format" />
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect summary rows of the Defect Detail Report -->
	<xsl:template name="detail_defect_summary_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="summary"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="summary/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:value-of select="summary" disable-output-escaping = "yes" />
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="workaround"> <!-- hide row if all fields are hidden -->
						<xsl:if test="string-length(workaround)>0 or boolean($DisplayEmptyFields)=true()">
							<tr>
								<td xsl:use-attribute-sets="report-detail-notes-title-format">
									<xsl:value-of select="workaround/@field-label" disable-output-escaping = "yes" />
								</td>
								<td xsl:use-attribute-sets="report-detail-notes-format">
										<xsl:value-of select="workaround" disable-output-escaping = "yes"/>
								</td>
							</tr>
						</xsl:if>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect found by rows of the Defect Detail Report -->
	<xsl:template name="detail_defect_foundby_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="found-by or date-found"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="found-by/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:for-each select="found-by">
										<xsl:call-template name="display_user_name" />
									</xsl:for-each>
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="date-found/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="date-found" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format" />
						</tr>
					</xsl:if>
					<xsl:if test="version-found"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="version-found/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="version-found" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format" />
							<td xsl:use-attribute-sets="report-detail-cell-format" />
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect description rows of the Defect Detail Report -->
	<xsl:template name="detail_defect_description_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="description and (string-length(description)>0 or boolean($DisplayEmptyFields)=true())">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="description/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
									<xsl:value-of select="description" disable-output-escaping = "yes"/>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="reproduced and (string-length(reproduced)>0 or boolean($DisplayEmptyFields)=true())">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="reproduced/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="reproduced" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="steps-to-reproduce and (string-length(steps-to-reproduce)>0 or boolean($DisplayEmptyFields)=true())">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="steps-to-reproduce/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
									<xsl:value-of select="steps-to-reproduce" disable-output-escaping = "yes"/>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="computer-config and (string-length(computer-config)>0 or boolean($DisplayEmptyFields)=true())">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="computer-config/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="computer-config" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="other-hardware-and-software and (string-length(other-hardware-and-software)>0 or boolean($DisplayEmptyFields)=true())">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="other-hardware-and-software/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
									<xsl:value-of select="other-hardware-and-software" disable-output-escaping = "yes"/>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="attachment-list">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="attachment-list/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format" />
						</tr>
						<xsl:for-each select="attachment-list/attachment">
							<tr>
								<td xsl:use-attribute-sets="report-detail-notes-title-format" />
								<td xsl:use-attribute-sets="report-detail-notes-format">
									<span class="DefectDetailRowDataClass">
										<xsl:value-of select="@name" disable-output-escaping = "yes" />
									</span>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect found by events for the Defect Detail Report -->
	<xsl:template name="detail_defect_foundby_events">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:for-each select="reported-by-record">
						<xsl:call-template name="detail_defect_foundby_rows" />
						<xsl:call-template name="detail_defect_description_rows" />
						<xsl:if test="position()!=last()">
							<tr>
								<td>
									<HR xsl:use-attribute-sets="report-detail-event-rule-format" />
								</td>
							</tr>
						</xsl:if>
					</xsl:for-each>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect custom field rows of the Defect Detail Report -->
	<xsl:template name="detail_defect_customfield_rows">
		<xsl:if test="custom-field-value">
			<tr>
				<td>
					<table xsl:use-attribute-sets="report-detail-table-format">
						<xsl:for-each select="custom-field-value">
							<tr>
								<td xsl:use-attribute-sets="report-detail-notes-title-format">
									<xsl:value-of select="@field-name " disable-output-escaping = "yes" />
									<xsl:text>: </xsl:text>
								</td>
								<td xsl:use-attribute-sets="report-detail-notes-format">
									<xsl:value-of select="@field-value" disable-output-escaping = "yes" />
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

<!-- Displays any Type of Event for the Defect Detail Report-->
	<xsl:template name="defect_detail_event">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<tr>
						<td>
							<table xsl:use-attribute-sets="report-detail-table-format">
								<xsl:if test="event-assigned-to or event-author or event-date"> <!-- hide row if all fields are hidden -->
									<tr>
										<xsl:if test="event-assigned-to">  <!-- hide column if not an assigned to event -->
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="event-assigned-to/assigned-to-user/@field-label" disable-output-escaping = "yes" />
												<span class="DefectDetailRowDataClass">
													<xsl:for-each select="event-assigned-to">
														<xsl:for-each select="assigned-to-user">
															<xsl:call-template name="display_user_name" />
															<xsl:if test="position()!=last()">; </xsl:if>
														</xsl:for-each>
													</xsl:for-each>
												</span>
											</td>
										</xsl:if>	
										<xsl:if test="event-author">  <!-- hide column if not an assigned to event -->
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="event-author/@field-label" disable-output-escaping = "yes" />
												<span class="DefectDetailRowDataClass">
													<xsl:for-each select="event-author">
														<xsl:call-template name="display_user_name" />
													</xsl:for-each>
												</span>
											</td>
										</xsl:if>
										<xsl:if test="event-date">  <!-- hide column if not an assigned to event -->
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="event-date/@field-label" disable-output-escaping = "yes" />														<span class="DefectDetailRowDataClass">
													<xsl:value-of select="event-date" disable-output-escaping = "yes" />
												</span>
											</td>
										</xsl:if>
										<td xsl:use-attribute-sets="report-detail-cell-format" />
									</tr>
								</xsl:if>
								<xsl:if test="time-spent or resulting-state or release-notes-version"> 
									<tr>
										<xsl:if test="time-spent">
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="time-spent/@field-label" disable-output-escaping = "yes" />
												<span class="DefectDetailRowDataClass">
													<xsl:value-of select="time-spent" disable-output-escaping = "yes" />
												</span>
											</td>
										</xsl:if>
										<xsl:if test="resulting-state">
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="resulting-state/state-name/@field-label" disable-output-escaping = "yes" />
												<span class="DefectDetailRowDataClass">
													<xsl:if test="(string-length(resulting-state/attribute) = 0) and (string-length(resulting-state/state-name) = 0)">
      														Unknown
     										 			</xsl:if>
													<xsl:if test="(string-length(resulting-state/attribute) > 0)">
														<xsl:value-of select="resulting-state/attribute" disable-output-escaping = "yes" />
														<xsl:if test="(string-length(resulting-state/state-name) > 0)">, </xsl:if>
													</xsl:if>
													<xsl:if test=" (string-length(resulting-state/state-name) > 0)">
														<xsl:value-of select="resulting-state/state-name" disable-output-escaping = "yes" />
													</xsl:if>
												</span>
											</td>
										</xsl:if>
										<xsl:if test="release-notes-version">  <!-- hide column if not an assigned to event -->
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="release-notes-version/@field-label" disable-output-escaping = "yes" />
												<span class="DefectDetailRowDataClass">
													<xsl:value-of select="release-notes-version" disable-output-escaping = "yes" />
												</span>
											</td>
										</xsl:if>
									</tr>
								</xsl:if>
								<xsl:if test="custom-field-value">
									<tr>
										<xsl:for-each select="custom-field-value">
											<td xsl:use-attribute-sets="report-detail-cell-format">
												<xsl:value-of select="@field-name" disable-output-escaping = "yes" />
												<text>: </text>
												<span class="DefectDetailRowDataClass">
													<xsl:value-of select="@field-value" disable-output-escaping = "yes" />
												</span>
											</td>
											<!-- generate a new row every 3rd column -->
											<xsl:if test="((position() mod 3) = 0)">
												<xsl:text disable-output-escaping="yes">&lt;/tr&gt;&lt;tr&gt;</xsl:text>
											</xsl:if>	
										</xsl:for-each>
									</tr>
								</xsl:if>
							</table>
						</td>
					</tr>
					<xsl:if test="notes and (string-length(notes)>0 or boolean($DisplayEmptyFields)=true())">
						<tr>
							<td>
								<table xsl:use-attribute-sets="report-detail-table-format">
									<tr>
										<td xsl:use-attribute-sets="report-detail-notes-title-format">
											<xsl:value-of select="notes/@field-label" disable-output-escaping = "yes" />
										</td>
										<td xsl:use-attribute-sets="report-detail-notes-format">
												<xsl:value-of select="notes" disable-output-escaping = "yes"/>
										</td>
									</tr>
								</table>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="attachment-list">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="attachment-list/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format" />
						</tr>
						<xsl:for-each select="attachment-list/attachment">
							<tr>
								<td xsl:use-attribute-sets="report-detail-notes-title-format" />
								<td xsl:use-attribute-sets="report-detail-notes-format">
									<span class="DefectDetailRowDataClass">
										<xsl:value-of select="@name" disable-output-escaping = "yes" />
									</span>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:if>
				</table>
			</td>
		</tr>		
	</xsl:template> 

	<!-- Displays the SCC Files for the Defect Detail Report -->
	<xsl:template name="detail_defect_scc_files">
		<xsl:for-each select="scc-file-list">
			<tr>
				<td>
					<table xsl:use-attribute-sets="report-detail-table-format">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format" />
							<td xsl:use-attribute-sets="report-detail-sccfilecell-format" />
							<td xsl:use-attribute-sets="report-detail-sccfilecell-format" />
						</tr>
						<xsl:for-each select="scc-file">
							<tr>
								<td xsl:use-attribute-sets="report-detail-notes-format" colspan="2">
									<xsl:apply-templates />
								</td>
								<td xsl:use-attribute-sets="report-detail-sccfilecell-format">
									<span class="DefectDetailRowTitleClass">Date Fixed: </span>
									<xsl:value-of select="@date-time-fixed" disable-output-escaping = "yes" />
								</td>
								<td xsl:use-attribute-sets="report-detail-sccfilecell-format">
									<span class="DefectDetailRowTitleClass">Revision Fixed: </span>
									<xsl:value-of select="@revision-fixed" disable-output-escaping = "yes" />
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>

	<!-- Displays the defect created by rows for the Defect Detail Report -->
	<xsl:template name="detail_defect_createdby_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="created-by"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="created-by/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:for-each select="created-by">
									<xsl:call-template name="display_user_name" />
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="date-created"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="date-created/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:value-of select="date-created" disable-output-escaping = "yes" />
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="creation-method"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="creation-method/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:value-of select="creation-method" disable-output-escaping = "yes" />
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="last-modified-by"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="last-modified-by/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:for-each select="last-modified-by">
									<xsl:call-template name="display_user_name" />
								</xsl:for-each>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="last-modified-by"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="date-last-modified/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:value-of select="date-last-modified" disable-output-escaping = "yes" />
							</td>
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Defect Detail Report XML Parsing -->
	<xsl:template name="defect">
		<xsl:for-each select="defect">
			<table border="1" frame="above" width="100%">
				<xsl:call-template name="detail_defect_header_rows" />
				<xsl:call-template name="detail_defect_status_rows" />
				<xsl:call-template name="detail_defect_summary_rows" />
				<xsl:call-template name="detail_defect_customfield_rows" />
				<xsl:call-template name="detail_defect_scc_files" />
				<xsl:call-template name="detail_defect_foundby_events" />
				<xsl:for-each select="defect-event">
					<xsl:sort select="event-date-seconds" data-type="number" />
					<xsl:call-template name="defect_detail_event" />
				</xsl:for-each>
				<xsl:call-template name="detail_defect_createdby_rows" />
			</table>
			<xsl:if test="((ancestor::TestTrackData/include_page_breaks) and (position()!=last()))">
				<DIV style="page-break-after:always"></DIV>
				<xsl:call-template name="pageheader" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- Detail Report XML Parsing -->
	<xsl:template match="/">
		<html>
			<head>
				<xsl:call-template name="DefineStyles" />
			</head>
			<body>
				<xsl:for-each select="TestTrackData">
					<xsl:call-template name="pageheader" />
					<xsl:call-template name="defect" />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
