<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:external="http://www.seapine.com" exclude-result-prefixes="external" id="TT V5.0 DefectHistoryReport.xslt">

	<xsl:output method="html" version="4.0" encoding="iso-8859-1" indent="yes" />

	<!-- Indicates whether empty fields should be displayed in the report -->
	<xsl:param name="DisplayEmptyFields" select="false()" />

	<!-- Contains the default settings for the table containing the page header -->
	<xsl:attribute-set name="defect-pageheader-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains external image tag for the image in the page header -->
	<xsl:attribute-set name="report-pageheader-image">
		<xsl:attribute name="src">
			<xsl:value-of select="external:get-server-image('seapinelogo.jpg')" disable-output-escaping = "yes" />
		</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for table cell containing the image in the page header -->
	<xsl:attribute-set name="report-pageheader-image-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report title in the page header -->
	<xsl:attribute-set name="report-pageheader-title-format">
		<xsl:attribute name="align">right</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the table containing the header info for each defect -->
	<xsl:attribute-set name="defect-header-row-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">2</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for cells within the header info for each defect -->
	<xsl:attribute-set name="defect-header-row-cell-format">
		<xsl:attribute name="width">33%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectHeaderRowClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the tables used within the detail portion of the report -->
	<xsl:attribute-set name="report-detail-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">3</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the 3-accross cells within the detail port of the report -->
	<xsl:attribute-set name="report-detail-cell-format">
		<xsl:attribute name="width">33%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the cells containing the title for note type fields -->
	<xsl:attribute-set name="report-detail-notes-title-format">
		<xsl:attribute name="width">15%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the cells containing the note type fields -->
	<xsl:attribute-set name="report-detail-notes-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report history  title cells -->
	<xsl:attribute-set name="report-detail-history-date-format">
		<xsl:attribute name="width">20%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the cells containing the note type fields -->
	<xsl:attribute-set name="report-detail-history-information-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DefectDetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>	
	

	<!-- Defines the default font settings used in the report -->
	<xsl:template name="DefineStyles">
		<!-- Default font settings for the title of the report displayed in the right hand area of the Report Header -->
		<STYLE>  
		 		.ReportTitleClass	{
					FONT-FAMILY: 'serif';
					FONT-SIZE: 30px;
					COLOR: #2B558A;
					FONT-WEIGHT:bold;
				}
	      </STYLE>
		<STYLE>  
		 		.DefectHeaderRowClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 11px;
					color: white;
					font-weight:bold;
					text-align: left;
					background-color:  #2B558A;
				}
	      </STYLE>
		<STYLE>  
		 		.DefectDetailRowTitleClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:bold;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
		<STYLE>  
		 		.DefectDetailRowDataClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:normal;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
	</xsl:template>

	<!-- Displays a user's name in the proper format -->
	<xsl:template name="display_user_name">
		<xsl:if test="(string-length(last-name) = 0) and (string-length(first-name) = 0)">
      			Unknown
      		</xsl:if>
		<xsl:if test="(string-length(last-name) > 0)">
			<xsl:value-of select="last-name" disable-output-escaping = "yes" />
			<xsl:if test="(string-length(first-name) > 0)">, </xsl:if>
		</xsl:if>
		<xsl:if test=" (string-length(first-name) > 0)">
			<xsl:value-of select="first-name" disable-output-escaping = "yes" />
		</xsl:if>
	</xsl:template>

	<!-- Outputs the Report Header -->
	<xsl:template name="pageheader">
		<table xsl:use-attribute-sets="defect-pageheader-table-format">
			<tr>
				<td xsl:use-attribute-sets="report-pageheader-image-format">
					<img xsl:use-attribute-sets="report-pageheader-image" />
				</td>
				<td xsl:use-attribute-sets="report-pageheader-title-format">
					<xsl:apply-templates select="ancestor-or-self::TestTrackData/Title" />
				</td>
			</tr>
		</table>
	</xsl:template>

	<!-- Displays the Defect Header Area of the Detail Report -->
	<xsl:template name="detail_defect_header_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="defect-header-row-table-format">
					<xsl:if test="defect-number or date-entered or product"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="defect-number/@field-label" disable-output-escaping = "yes" />
								<xsl:text></xsl:text>
								<xsl:value-of select="defect-number" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="date-entered/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="date-entered" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="product/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="product" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="entered-by or component"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">&#160;</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="entered-by/@field-label" disable-output-escaping = "yes" />
								<xsl:for-each select="entered-by">
									<xsl:call-template name="display_user_name" />
								</xsl:for-each>
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
							<td xsl:use-attribute-sets="defect-header-row-cell-format">
								<xsl:value-of select="component/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="component" disable-output-escaping = "yes" />
								&#160; <!-- Netscape ignores backgound color on empty cells if we don't do this-->
							</td>
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect status row of the Defect Detail Report -->
	<xsl:template name="detail_defect_status_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="defect-status or severity"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format" colspan="2">
								<xsl:value-of select="defect-status/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="defect-status" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="severity/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="severity" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="type or priority or disposition"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="type/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="type" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="priority/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="priority" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="disposition/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="disposition" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="reference"> <!-- hide row if field is hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-cell-format">
								<xsl:value-of select="reference/@field-label" disable-output-escaping = "yes" />
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="reference" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-cell-format" />
							<td xsl:use-attribute-sets="report-detail-cell-format" />
						</tr>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect summary rows of the Defect Detail Report -->
	<xsl:template name="detail_defect_summary_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:if test="summary"> <!-- hide row if all fields are hidden -->
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								<xsl:value-of select="summary/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
								<xsl:value-of select="summary" disable-output-escaping = "yes" />
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="workaround"> <!-- hide row if all fields are hidden -->
						<xsl:if test="string-length(workaround)>0 or boolean($DisplayEmptyFields)=true()">
							<tr>
								<td xsl:use-attribute-sets="report-detail-notes-title-format">
									<xsl:value-of select="workaround/@field-label" disable-output-escaping = "yes" />
								</td>
								<td xsl:use-attribute-sets="report-detail-notes-format">
										<xsl:value-of select="workaround" disable-output-escaping = "yes"/>
								</td>
							</tr>
						</xsl:if>
					</xsl:if>
					<xsl:if test="defect-event/@include-in-release-notes='yes' ">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notes-title-format">
								Release Notes: 
							</td>
						</tr>
						<xsl:for-each select="defect-event">
							<xsl:if test="@include-in-release-notes='yes' and (string-length(notes)>0 or boolean($DisplayEmptyFields)=true())">								<tr>
									<td xsl:use-attribute-sets="report-detail-notes-title-format" />
									<td xsl:use-attribute-sets="report-detail-notes-format">
											<xsl:value-of select="notes" disable-output-escaping = "yes"/>
									</td>
								</tr>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the defect History for the Defect Detail Report -->
	<xsl:template name="detail_defect_history_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<xsl:for-each select="historical-event">
						<tr>
							<td xsl:use-attribute-sets="report-detail-history-date-format">
								Date:
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="@date" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-history-information-format">
								Information:
								<span class="DefectDetailRowDataClass">
									<xsl:value-of select="@information" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Defect Detail Report XML Parsing -->
	<xsl:template name="defect">
		<xsl:for-each select="defect">
			<table border="1" frame="above" width="100%">
				<xsl:call-template name="detail_defect_header_rows" />
				<xsl:call-template name="detail_defect_status_rows" />
				<xsl:call-template name="detail_defect_summary_rows" />
				<xsl:call-template name="detail_defect_history_rows" />
			</table>
			<xsl:if test="((ancestor::TestTrackData/include_page_breaks) and (position()!=last()))">
				<DIV style="page-break-after:always"></DIV>
				<xsl:call-template name="pageheader" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- Detail Report XML Parsing -->
	<xsl:template match="/">
		<html>
			<head>
				<xsl:call-template name="DefineStyles" />
			</head>
			<body>
				<xsl:for-each select="TestTrackData">
					<xsl:call-template name="pageheader" />
					<xsl:call-template name="defect" />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
