<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:external="http://www.seapine.com" exclude-result-prefixes="external" id="TT V5.0 FilterDetailReport.xslt">

	<xsl:output method="html" version="4.0" encoding="iso-8859-1" indent="yes" />

	<!-- Indicates whether empty fields should be displayed in the report -->
	<xsl:param name="DisplayEmptyFields" select="true()" />

	<!-- Contains the default settings for the report title page header table -->
	<xsl:attribute-set name="pageheader-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report header image -->
	<xsl:attribute-set name="report-header-image">
		<xsl:attribute name="src">
			<xsl:value-of select="external:get-server-image('seapinelogo.jpg')" disable-output-escaping = "yes" />
		</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the image on the report title page header -->
	<xsl:attribute-set name="report-header-image-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report title on the report title page header -->
	<xsl:attribute-set name="report-header-title-format">
		<xsl:attribute name="align">right</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the defect header rows table -->
	<xsl:attribute-set name="header-row-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">2</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the defect header rows cells -->
	<xsl:attribute-set name="header-row-cell-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">HeaderRowClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail  tables -->
	<xsl:attribute-set name="report-detail-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">3</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail title cells -->
	<xsl:attribute-set name="report-detail-title-format">
		<xsl:attribute name="width">10%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail description title cells -->
	<xsl:attribute-set name="report-detail-descriptiontitle-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the description cell -->
	<xsl:attribute-set name="report-detail-description-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail description title cells -->
	<xsl:attribute-set name="restriction-cell-one-format">
		<xsl:attribute name="width">10%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the description cell -->
	<xsl:attribute-set name="restriction-cell-two-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<xsl:template name="DefineStyles">
		<STYLE>  
		 		.ReportTitleClass	{
					FONT-FAMILY: 'serif';
					FONT-SIZE: 30px;
					COLOR: #2B558A;
					FONT-WEIGHT:bold;
				}
	      </STYLE>
		<STYLE>  
		 		.HeaderRowClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 11px;
					color: white;
					font-weight:bold;
					text-align: left;
					background-color:  #2B558A;
				}
	      </STYLE>
		<STYLE>  
		 		.DetailRowTitleClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:bold;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
		<STYLE>  
		 		.DetailRowDataClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:normal;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
	</xsl:template>

	<!-- Outputs the Report Header -->
	<xsl:template name="pageheader">
		<table xsl:use-attribute-sets="defect-pageheader-table-format">
			<tr>
				<td xsl:use-attribute-sets="report-header-image-format">
					<img xsl:use-attribute-sets="report-header-image" />
				</td>
				<td xsl:use-attribute-sets="report-header-title-format">
					<xsl:apply-templates select="ancestor-or-self::TestTrackData/Title" />
				</td>
			</tr>
		</table>
	</xsl:template>

	<!--Displays the filter name header row row -->
	<xsl:template name="detail_filter_header_row">
		<tr>
			<td>
				<table xsl:use-attribute-sets="header-row-table-format">
					<tr>
						<td xsl:use-attribute-sets="header-row-cell-format">
							<xsl:value-of select="name/@field-label" disable-output-escaping = "yes" />
							<xsl:value-of select="name" disable-output-escaping = "yes" />
						</td>
					</tr>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the filter restrictions rows of the filter detail report -->
	<xsl:template name="detail_filter_restriction_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<tr>
						<td colspan="2" xsl:use-attribute-sets="report-detail-descriptiontitle-format">
							<xsl:value-of select="description/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="description" disable-output-escaping = "yes" />
							</span>
						</td>
					</tr>
					<tr>
						<td colspan="2" xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="restrictions/@field-label" disable-output-escaping = "yes" />
						</td>
					</tr>
					<xsl:for-each select="restrictions">
						<tr>
							<td xsl:use-attribute-sets="restriction-cell-one-format" />
							<td xsl:use-attribute-sets="restriction-cell-two-format">
								<xsl:apply-templates />
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Parses each filter in the report -->
	<xsl:template name="filter">
		<xsl:for-each select="filter">
			<table border="1" frame="above" width="100%">
				<xsl:call-template name="detail_filter_header_row" />
				<xsl:call-template name="detail_filter_restriction_rows" />
			</table>
			<xsl:if test="((ancestor::TestTrackData/include_page_breaks) and (position()!=last()))">
				<DIV style="page-break-after:always"></DIV>
				<xsl:call-template name="pageheader" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- Detail Report XML Parsing -->
	<xsl:template match="/">
		<html>
			<head>
				<xsl:call-template name="DefineStyles" />
			</head>
			<body>
				<xsl:for-each select="TestTrackData">
					<xsl:call-template name="pageheader" />
					<xsl:call-template name="filter" />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>