<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:external="http://www.seapine.com" exclude-result-prefixes="external" id="TT V5.0 TestConfigDetailReport.xslt">

	<xsl:output method="html" version="4.0" encoding="iso-8859-1" indent="yes" />

	<!-- Indicates whether empty fields should be displayed in the report -->
	<xsl:param name="DisplayEmptyFields" select="true()" />

	<!-- Contains the default settings for the report title page header table -->
	<xsl:attribute-set name="pageheader-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report header image -->
	<xsl:attribute-set name="report-header-image">
		<xsl:attribute name="src">
			<xsl:value-of select="external:get-server-image('seapinelogo.jpg')" disable-output-escaping = "yes" />
		</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the image on the report title page header -->
	<xsl:attribute-set name="report-header-image-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report title on the report title page header -->
	<xsl:attribute-set name="report-header-title-format">
		<xsl:attribute name="align">right</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail  tables -->
	<xsl:attribute-set name="report-detail-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">3</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the header rows table -->
	<xsl:attribute-set name="header-row-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">2</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the header rows cells -->
	<xsl:attribute-set name="header-row-cell-format">
		<xsl:attribute name="width">33%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">HeaderRowClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail title cells -->
	<xsl:attribute-set name="detail-title-format">
		<xsl:attribute name="width">50%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail  tables -->
	<xsl:attribute-set name="detail-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">3</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail description title cells -->
	<xsl:attribute-set name="description-title-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the description cell -->
	<xsl:attribute-set name="description-data-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<xsl:template name="DefineStyles">
		<!-- Default font settings for the title of the report displayed in the right hand area of the Report Header -->
		<STYLE>  
		 		.ReportTitleClass	{
					FONT-FAMILY: 'serif';
					FONT-SIZE: 30px;
					COLOR: #2B558A;
					FONT-WEIGHT:bold;
				}
	      </STYLE>
		<STYLE>  
		 		.HeaderRowClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 11px;
					color: white;
					font-weight:bold;
					text-align: left;
					background-color:  #2B558A;
				}
	      </STYLE>
		<STYLE>  
		 		.DetailRowTitleClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:bold;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
		<STYLE>  
		 		.DetailRowDataClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:normal;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
	</xsl:template>

	<!-- Outputs the Report Header -->
	<xsl:template name="pageheader">
		<table xsl:use-attribute-sets="pageheader-table-format">
			<tr>
				<td xsl:use-attribute-sets="report-header-image-format">
					<img xsl:use-attribute-sets="report-header-image" />
				</td>
				<td xsl:use-attribute-sets="report-header-title-format">
					<xsl:apply-templates select="ancestor-or-self::TestTrackData/Title" />
				</td>
			</tr>
		</table>
	</xsl:template>

	<!--Displays the test config header row -->
	<xsl:template name="detail_testconfig_header_row">
		<tr>
			<td>
				<table xsl:use-attribute-sets="header-row-table-format">
					<tr>
						<td xsl:use-attribute-sets="header-row-cell-format">
							<xsl:value-of select="name/@field-label" disable-output-escaping = "yes" />
							<xsl:value-of select="name" disable-output-escaping = "yes" />
						</td>
					</tr>
				</table>
			</td>
		</tr>
	</xsl:template>
	<!-- Displays the detail about a single test config -->
	<xsl:template name="detail_testconfig_detail_rows">
		<xsl:for-each select="base-test-config">
			<tr>
				<td>
					<table xsl:use-attribute-sets="report-detail-table-format">
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="model/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="model" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="brand/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="brand" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="operating-system/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="operating-system" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="os-version/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="os-version" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="cpu-type/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="cpu-type" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="processor-clock-speed-in-mhz/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="processor-clock-speed-in-mhz" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(processor-clock-speed-in-mhz))) > 0">
										<xsl:text> MHz</xsl:text>
									</xsl:if>
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="ram-in-mb/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="ram-in-mb" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(ram-in-mb))) > 0">
										<xsl:text> MB</xsl:text>
									</xsl:if>
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="rom-in-mb/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="rom-in-mb" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(rom-in-mb))) > 0">
										<xsl:text> MB</xsl:text>
									</xsl:if>
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="video-controller/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="video-controller" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="has-multiple-monitors/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="has-multiple-monitors/@value" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="hard-disk-type/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="hard-disk-type" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="hard-disk-size-in-mb/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="hard-disk-size-in-mb" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(hard-disk-size-in-mb))) > 0">
										<xsl:text> MB</xsl:text>
									</xsl:if>
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="cdrom/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="cdrom" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="printer/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="printer" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="modem/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="modem" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="detail-title-format">
								<xsl:value-of select="scanner/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="scanner" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td colspan="2" xsl:use-attribute-sets="description-title-format">
								<xsl:value-of select="other-hardware-and-software/@field-label" disable-output-escaping = "yes" />
									<xsl:value-of select="other-hardware-and-software" disable-output-escaping = "yes"/>
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>

	<!-- Parses the test config nodes in the xml data -->
	<xsl:template name="testconfig">
		<xsl:for-each select="test-config">
			<table border="1" frame="above" width="100%">
				<xsl:call-template name="detail_testconfig_header_row" />
				<xsl:call-template name="detail_testconfig_detail_rows" />
			</table>
			<xsl:if test="((ancestor::TestTrackData/include_page_breaks) and (position()!=last()))">
				<DIV style="page-break-after:always"></DIV>
				<xsl:call-template name="pageheader" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- Detail Report XML Parsing -->
	<xsl:template match="/">
		<html>
			<head>
				<xsl:call-template name="DefineStyles" />
			</head>
			<body>
				<xsl:for-each select="TestTrackData">
					<xsl:call-template name="pageheader" />
					<xsl:call-template name="testconfig" />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
