<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:external="http://www.seapine.com" exclude-result-prefixes="external" id="TT V5.0 UserDetailReport.xslt">

	<xsl:output method="html" version="4.0" encoding="iso-8859-1" indent="yes" />

	<!-- Indicates whether empty fields should be displayed in the report -->
	<xsl:param name="DisplayEmptyFields" select="true()" />

	<!-- Contains the default settings for the report title page header table -->
	<xsl:attribute-set name="defect-pageheader-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report header image -->
	<xsl:attribute-set name="report-header-image">
		<xsl:attribute name="src">
			<xsl:value-of select="external:get-server-image('seapinelogo.jpg')" disable-output-escaping = "yes" />
		</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the image on the report title page header -->
	<xsl:attribute-set name="report-header-image-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report title on the report title page header -->
	<xsl:attribute-set name="report-header-title-format">
		<xsl:attribute name="align">right</xsl:attribute>
		<xsl:attribute name="valign">middle</xsl:attribute>
		<xsl:attribute name="class">ReportTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the defect header rows table -->
	<xsl:attribute-set name="user-header-row-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">2</xsl:attribute>
		<xsl:attribute name="cellspacing">0</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail  tables -->
	<xsl:attribute-set name="report-detail-table-format">
		<xsl:attribute name="width">100%</xsl:attribute>
		<xsl:attribute name="border">0</xsl:attribute>
		<xsl:attribute name="cellpadding">0</xsl:attribute>
		<xsl:attribute name="cellspacing">3</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the user header rows cells -->
	<xsl:attribute-set name="user-header-row-cell-format">
		<xsl:attribute name="width">25%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">ReportHeaderRowClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail title cells -->
	<xsl:attribute-set name="report-detail-title-format">
		<xsl:attribute name="width">33%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report event notes  title cells -->
	<xsl:attribute-set name="report-detail-notestitle-format">
		<xsl:attribute name="width">5%</xsl:attribute>
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report event notes detail cell -->
	<xsl:attribute-set name="report-detail-notes-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowDataClass</xsl:attribute>
	</xsl:attribute-set>

	<!-- Contains the default settings for the report detail title cells -->
	<xsl:attribute-set name="report-footnote-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">FootnoteClass</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name="report-detail-otherhardwareandsoftware-format">
		<xsl:attribute name="align">left</xsl:attribute>
		<xsl:attribute name="valign">top</xsl:attribute>
		<xsl:attribute name="class">DetailRowTitleClass</xsl:attribute>
	</xsl:attribute-set>

	<xsl:template name="DefineStyles">
		<!-- Default font settings for the title of the report displayed in the right hand area of the Report Header -->
		<STYLE>  
		 		.ReportTitleClass	{
					FONT-FAMILY: 'serif';
					FONT-SIZE: 30px;
					COLOR: #2B558A;
					FONT-WEIGHT:bold;
				}
	      </STYLE>
		<STYLE>  
		 		.ReportHeaderRowClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 11px;
					color: white;
					font-weight:bold;
					text-align: left;
					background-color:  #2B558A;
				}
	      </STYLE>
		<STYLE>  
		 		.DetailRowTitleClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:bold;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
		<STYLE>  
		 		.DetailRowDataClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:normal;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
		<STYLE>  
		 		.FootnoteClass
				{
					font-family: Verdana, Arial, Helvetica, sans-serif;
					font-size: 10px;
					color: black;
					font-weight:normal;
					text-align: left;
					background-color:  white;
				}
	      </STYLE>
	</xsl:template>

	<!-- Displays a user's name in the proper format -->
	<xsl:template name="display_user_name">
		<xsl:if test="(string-length(last-name) = 0) and (string-length(first-name) = 0)">
      			Unknown
      		</xsl:if>
		<xsl:if test="(string-length(last-name) > 0)">
			<xsl:value-of select="last-name" disable-output-escaping = "yes" />
			<xsl:if test="(string-length(first-name) > 0)">, </xsl:if>
		</xsl:if>
		<xsl:if test=" (string-length(first-name) > 0)">
			<xsl:value-of select="first-name" disable-output-escaping = "yes" />
		</xsl:if>
	</xsl:template>

	<!-- Outputs the Report Header -->
	<xsl:template name="pageheader">
		<table xsl:use-attribute-sets="defect-pageheader-table-format">
			<tr>
				<td xsl:use-attribute-sets="report-header-image-format">
					<img xsl:use-attribute-sets="report-header-image" />
				</td>
				<td xsl:use-attribute-sets="report-header-title-format">
					<xsl:apply-templates select="ancestor-or-self::TestTrackData/Title" />
				</td>
			</tr>
		</table>
	</xsl:template>

	<!-- Displays the user name and address information -->
	<xsl:template name="detail_user_header_row">
		<tr>
			<td>
				<table xsl:use-attribute-sets="user-header-row-table-format">
					<tr>
						<td xsl:use-attribute-sets="user-header-row-cell-format" width="100%" colspan="2">
							<xsl:value-of select="full-name/@field-label" disable-output-escaping = "yes" />
							<xsl:for-each select="full-name">
								<xsl:call-template name="display_user_name" />
							</xsl:for-each>
						</td>
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="user-group-name/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="user-group-name" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="login-name/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="login-name" disable-output-escaping = "yes" />
							</span>
						</td>
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="primary-telephone-number/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="primary-telephone-number" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="secondary-telephone-number/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="secondary-telephone-number" disable-output-escaping = "yes" />
							</span>
						</td>
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:text>e-mail: </xsl:text>
							<span class="DetailRowDataClass">
								<xsl:value-of select="email-address/@field-label" disable-output-escaping = "yes" />
								<xsl:value-of select="email-address" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format" />
					</tr>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Displays the user notes row -->
	<xsl:template name="detail_user_notes_rows">
		<xsl:if test="string-length(notes)>0 or boolean($DisplayEmptyFields)=true()">
			<tr>
				<td>
					<table xsl:use-attribute-sets="report-detail-table-format">
						<tr>
							<td xsl:use-attribute-sets="report-detail-notestitle-format">
								<xsl:value-of select="notes/@field-label" disable-output-escaping = "yes" />
							</td>
							<td xsl:use-attribute-sets="report-detail-notes-format">
									<xsl:value-of select="notes" disable-output-escaping = "yes"/>
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- Displays the computer configuration for the user-->
	<xsl:template name="detail_user_computerconfig_rows">
		<xsl:for-each select="base-test-config">
			<tr>
				<td>
					<table xsl:use-attribute-sets="report-detail-table-format">
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<i>Computer Configuration</i>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format" />
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="model/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="model" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="brand/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="brand" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="operating-system/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="operating-system" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="os-version/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="os-version" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="cpu-type/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="cpu-type" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="processor-clock-speed-in-mhz/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="processor-clock-speed-in-mhz" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(processor-clock-speed-in-mhz))) > 0">
										<xsl:text> MHz</xsl:text>
									</xsl:if>
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="ram-in-mb/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="ram-in-mb" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(ram-in-mb))) > 0">
										<xsl:text> MB</xsl:text>
									</xsl:if>
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="rom-in-mb/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="rom-in-mb" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(rom-in-mb))) > 0">
										<xsl:text> MB</xsl:text>
									</xsl:if>
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="video-controller/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="video-controller" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="has-multiple-monitors/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="has-multiple-monitors/@value" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="hard-disk-type/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="hard-disk-type" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="hard-disk-size-in-mb/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="hard-disk-size-in-mb" disable-output-escaping = "yes" />
									<xsl:if test="string-length(normalize-space(string(hard-disk-size-in-mb))) > 0">
										<xsl:text> MB</xsl:text>
									</xsl:if>
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="cdrom/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="cdrom" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="printer/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="printer" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="modem/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="modem" disable-output-escaping = "yes" />
								</span>
							</td>
							<td xsl:use-attribute-sets="report-detail-title-format">
								<xsl:value-of select="scanner/@field-label" disable-output-escaping = "yes" />
								<span class="DetailRowDataClass">
									<xsl:value-of select="scanner" disable-output-escaping = "yes" />
								</span>
							</td>
						</tr>
						<tr>
							<td xsl:use-attribute-sets="report-detail-otherhardwareandsoftware-format" colspan="2">
								<xsl:value-of select="other-hardware-and-software/@field-label" disable-output-escaping = "yes" />
									<xsl:value-of select="other-hardware-and-software" disable-output-escaping = "yes"/>
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>

	<!-- Displays the defects report by user rows -->
	<xsl:template name="detail_user_stats_rows">
		<tr>
			<td>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="last-logged-in/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="last-logged-in" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format" />
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="defects-reported/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="defects-reported" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="date-last-defect-reported/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="date-last-defect-reported" disable-output-escaping = "yes" />
							</span>
						</td>
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="defects-currently-assigned/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="defects-currently-assigned" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format" />
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="defects-fixed/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="defects-fixed" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="time-spent-fixing-defects/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="time-spent-fixing-defects" disable-output-escaping = "yes" />
							</span>
						</td>
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="defects-verified/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="defects-verified" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format" />
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="defects-closed/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="defects-closed" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format" />
					</tr>
					<tr>
						<td xsl:use-attribute-sets="report-detail-title-format">
							<xsl:value-of select="defects-reopened/@field-label" disable-output-escaping = "yes" />
							<span class="DetailRowDataClass">
								<xsl:value-of select="defects-reopened" disable-output-escaping = "yes" />
							</span>
						</td>
						<td xsl:use-attribute-sets="report-detail-title-format" />
					</tr>
				</table>
				<table xsl:use-attribute-sets="report-detail-table-format">
					<tr>
						<td xsl:use-attribute-sets="report-footnote-format">
							<i>
								<xsl:text>Note: Percentages represent % of total </xsl:text>
								<xsl:value-of select="ancestor::TestTrackData/total-defects/@field-label" disable-output-escaping = "yes" />
								<xsl:text> (</xsl:text>
								<xsl:value-of select="ancestor::TestTrackData/total-defects" disable-output-escaping = "yes" />
								<xsl:text>) </xsl:text>
								<xsl:text>in the project file.</xsl:text>
							</i>
						</td>
					</tr>
				</table>
			</td>
		</tr>
	</xsl:template>

	<!-- Parses out the user nodes in the XML-->
	<xsl:template name="user">
		<xsl:for-each select="user">
			<table border="1" frame="above" width="100%">
				<xsl:call-template name="detail_user_header_row" />
				<xsl:call-template name="detail_user_notes_rows" />
				<xsl:call-template name="detail_user_computerconfig_rows" />
				<xsl:call-template name="detail_user_stats_rows" />
			</table>
			<xsl:if test="((ancestor::TestTrackData/include_page_breaks) and (position()!=last()))">
				<DIV style="page-break-after:always"></DIV>
				<xsl:call-template name="pageheader" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- Detail Report XML Parsing -->
	<xsl:template match="/">
		<html>
			<head>
				<xsl:call-template name="DefineStyles" />
			</head>
			<body>
				<xsl:for-each select="TestTrackData">
					<xsl:call-template name="pageheader" />
					<xsl:call-template name="user" />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
